"""Add alarm priority

Revision ID: 78e80c3339ff
Revises: 5ccf897e51af
Create Date: 2020-12-02 14:22:02.925553

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '78e80c3339ff'
down_revision = '5ccf897e51af'
branch_labels = None
depends_on = None


def upgrade():
    op.execute('ALTER TABLE alarms ADD COLUMN priority integer default 0;')
    pass


def downgrade():
    op.execute('ALTER TABLE alarms DROP COLUMN priority;')
    pass



import json

from aiohttp import web
from asyncpg.exceptions import ForeignKeyViolationError

from marshmallow import ValidationError

from .schemas import listeners_schema, listener_schema
from .views import ValidatingView, paginate_query


class ListenersView(ValidatingView):
    async def get(self):
        async with self.request.app['db_pool'].acquire() as conn:
            query = ('SELECT * from listeners', )
            tags = await conn.fetch(*paginate_query(self.request, query))
            return web.json_response(listeners_schema.dump(tags))


class ListenerView(ValidatingView):
    async def get(self):
        l_id = self.request.match_info['id']
        async with self.request.app['db_pool'].acquire() as conn:
            l = await conn.fetchrow('SELECT * FROM listeners WHERE id = $1', l_id)
            if not l:
                raise web.HTTPNotFound
            return web.json_response(listener_schema.dump(l))

    async def patch(self):
        l_id = self.request.match_info['id']
        async with self.request.app['db_pool'].acquire() as conn:
            l_row = await conn.fetchrow('SELECT name, zone_id, attrs FROM listeners WHERE id = $1', l_id)
            if not l_row:
                raise web.HTTPNotFound
            from_db = listener_schema.load(dict(l_row.items()))
            body = await self._valid_json(self.request)
            new = self._validate(listener_schema, body)
            from_db.update(new)
            try:
                await conn.execute('UPDATE listeners SET name = $1, zone_id = $2, attrs = $3 WHERE id = $4',
                                   from_db['name'], from_db['zone_id'], json.dumps(from_db['attrs']), l_id)
            except ForeignKeyViolationError as e:
                raise web.HTTPBadRequest(reason=f'Invalid zone_id = {from_db["zone_id"]}')
        raise web.HTTPNoContent



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: c3loc/proto/management.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='c3loc/proto/management.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1c\x63\x33loc/proto/management.proto\"\xfa\x01\n\x08Response\x12\n\n\x02id\x18\x01 \x01(\r\x12\'\n\x06status\x18\x02 \x01(\x0e\x32\x17.Response.RequestStatus\x12\r\n\x05\x65rror\x18\x03 \x01(\t\x12$\n\x06\x63onfig\x18\x04 \x01(\x0b\x32\x12.GetConfigResponseH\x00\x12\x33\n\x0c\x62\x65\x61\x63on_count\x18\x05 \x01(\x0b\x32\x1b.CurrentBeaconCountResponseH\x00\x12\x10\n\x06syslog\x18\x06 \x01(\tH\x00\"2\n\rRequestStatus\x12\x06\n\x02OK\x10\x00\x12\r\n\tMALFORMED\x10\x01\x12\n\n\x06\x46\x41ILED\x10\x02\x42\t\n\x07payload\"\x81\x02\n\x07Request\x12\n\n\x02id\x18\x01 \x01(\r\x12\x15\n\x04ping\x18\x02 \x01(\x0b\x32\x05.PingH\x00\x12\x1c\n\x06\x63onfig\x18\x03 \x01(\x0b\x32\n.GetConfigH\x00\x12\x19\n\x06reboot\x18\x04 \x01(\x0b\x32\x07.RebootH\x00\x12\x1e\n\x08settings\x18\x05 \x01(\x0b\x32\n.SetConfigH\x00\x12,\n\rcount_request\x18\x06 \x01(\x0b\x32\x13.CurrentBeaconCountH\x00\x12#\n\x08\x66irmware\x18\x07 \x01(\x0b\x32\x0f.FirmwareUpdateH\x00\x12\x1c\n\x06syslog\x18\x08 \x01(\x0b\x32\n.GetSyslogH\x00\x42\t\n\x07\x63ommand\"\x06\n\x04Ping\"\x08\n\x06Reboot\"\x14\n\x12\x43urrentBeaconCount\"\x0b\n\tGetSyslog\"\x18\n\tGetConfig\x12\x0b\n\x03key\x18\x01 \x03(\t\")\n\tSetConfig\x12\x1c\n\x06values\x18\x01 \x03(\x0b\x32\x0c.ConfigValue\"1\n\x11GetConfigResponse\x12\x1c\n\x06values\x18\x01 \x03(\x0b\x32\x0c.ConfigValue\">\n\x1a\x43urrentBeaconCountResponse\x12\x11\n\ttimestamp\x18\x01 \x01(\r\x12\r\n\x05\x63ount\x18\x02 \x01(\r\"1\n\nConfigList\x12#\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x12.GetConfigResponse\"\x1c\n\x0bStringArray\x12\r\n\x05\x61rray\x18\x01 \x03(\t\"\xc8\x01\n\x0b\x43onfigValue\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x16\n\x0cvalue_string\x18\x02 \x01(\tH\x00\x12\x16\n\x0cvalue_double\x18\x03 \x01(\x01H\x00\x12\x17\n\rvalue_integer\x18\x04 \x01(\x03H\x00\x12\x17\n\rvalue_boolean\x18\x05 \x01(\x08H\x00\x12\x1b\n\x04list\x18\x06 \x01(\x0b\x32\x0b.ConfigListH\x00\x12$\n\x0cstring_array\x18\x07 \x01(\x0b\x32\x0c.StringArrayH\x00\x42\x07\n\x05value\"@\n\x0e\x46irmwareUpdate\x12\r\n\x05image\x18\x01 \x01(\x0c\x12\x11\n\tdowngrade\x18\x02 \x01(\x08\x12\x0c\n\x04last\x18\x03 \x01(\x08\"\x1c\n\x0bHealthCheck\x12\r\n\x05\x63lock\x18\x01 \x01(\x03\x62\x06proto3'
)



_RESPONSE_REQUESTSTATUS = _descriptor.EnumDescriptor(
  name='RequestStatus',
  full_name='Response.RequestStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OK', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MALFORMED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=222,
  serialized_end=272,
)
_sym_db.RegisterEnumDescriptor(_RESPONSE_REQUESTSTATUS)


_RESPONSE = _descriptor.Descriptor(
  name='Response',
  full_name='Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Response.id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='Response.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='Response.error', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='Response.config', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='beacon_count', full_name='Response.beacon_count', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='syslog', full_name='Response.syslog', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RESPONSE_REQUESTSTATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='payload', full_name='Response.payload',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=33,
  serialized_end=283,
)


_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Request.id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ping', full_name='Request.ping', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='Request.config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reboot', full_name='Request.reboot', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settings', full_name='Request.settings', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count_request', full_name='Request.count_request', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='firmware', full_name='Request.firmware', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='syslog', full_name='Request.syslog', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='command', full_name='Request.command',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=286,
  serialized_end=543,
)


_PING = _descriptor.Descriptor(
  name='Ping',
  full_name='Ping',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=545,
  serialized_end=551,
)


_REBOOT = _descriptor.Descriptor(
  name='Reboot',
  full_name='Reboot',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=553,
  serialized_end=561,
)


_CURRENTBEACONCOUNT = _descriptor.Descriptor(
  name='CurrentBeaconCount',
  full_name='CurrentBeaconCount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=563,
  serialized_end=583,
)


_GETSYSLOG = _descriptor.Descriptor(
  name='GetSyslog',
  full_name='GetSyslog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=585,
  serialized_end=596,
)


_GETCONFIG = _descriptor.Descriptor(
  name='GetConfig',
  full_name='GetConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='GetConfig.key', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=598,
  serialized_end=622,
)


_SETCONFIG = _descriptor.Descriptor(
  name='SetConfig',
  full_name='SetConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='SetConfig.values', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=624,
  serialized_end=665,
)


_GETCONFIGRESPONSE = _descriptor.Descriptor(
  name='GetConfigResponse',
  full_name='GetConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='GetConfigResponse.values', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=667,
  serialized_end=716,
)


_CURRENTBEACONCOUNTRESPONSE = _descriptor.Descriptor(
  name='CurrentBeaconCountResponse',
  full_name='CurrentBeaconCountResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CurrentBeaconCountResponse.timestamp', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='CurrentBeaconCountResponse.count', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=718,
  serialized_end=780,
)


_CONFIGLIST = _descriptor.Descriptor(
  name='ConfigList',
  full_name='ConfigList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='ConfigList.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=782,
  serialized_end=831,
)


_STRINGARRAY = _descriptor.Descriptor(
  name='StringArray',
  full_name='StringArray',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='array', full_name='StringArray.array', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=833,
  serialized_end=861,
)


_CONFIGVALUE = _descriptor.Descriptor(
  name='ConfigValue',
  full_name='ConfigValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ConfigValue.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value_string', full_name='ConfigValue.value_string', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value_double', full_name='ConfigValue.value_double', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value_integer', full_name='ConfigValue.value_integer', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value_boolean', full_name='ConfigValue.value_boolean', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='list', full_name='ConfigValue.list', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='string_array', full_name='ConfigValue.string_array', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='ConfigValue.value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=864,
  serialized_end=1064,
)


_FIRMWAREUPDATE = _descriptor.Descriptor(
  name='FirmwareUpdate',
  full_name='FirmwareUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='image', full_name='FirmwareUpdate.image', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='downgrade', full_name='FirmwareUpdate.downgrade', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last', full_name='FirmwareUpdate.last', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1066,
  serialized_end=1130,
)


_HEALTHCHECK = _descriptor.Descriptor(
  name='HealthCheck',
  full_name='HealthCheck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='clock', full_name='HealthCheck.clock', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1132,
  serialized_end=1160,
)

_RESPONSE.fields_by_name['status'].enum_type = _RESPONSE_REQUESTSTATUS
_RESPONSE.fields_by_name['config'].message_type = _GETCONFIGRESPONSE
_RESPONSE.fields_by_name['beacon_count'].message_type = _CURRENTBEACONCOUNTRESPONSE
_RESPONSE_REQUESTSTATUS.containing_type = _RESPONSE
_RESPONSE.oneofs_by_name['payload'].fields.append(
  _RESPONSE.fields_by_name['config'])
_RESPONSE.fields_by_name['config'].containing_oneof = _RESPONSE.oneofs_by_name['payload']
_RESPONSE.oneofs_by_name['payload'].fields.append(
  _RESPONSE.fields_by_name['beacon_count'])
_RESPONSE.fields_by_name['beacon_count'].containing_oneof = _RESPONSE.oneofs_by_name['payload']
_RESPONSE.oneofs_by_name['payload'].fields.append(
  _RESPONSE.fields_by_name['syslog'])
_RESPONSE.fields_by_name['syslog'].containing_oneof = _RESPONSE.oneofs_by_name['payload']
_REQUEST.fields_by_name['ping'].message_type = _PING
_REQUEST.fields_by_name['config'].message_type = _GETCONFIG
_REQUEST.fields_by_name['reboot'].message_type = _REBOOT
_REQUEST.fields_by_name['settings'].message_type = _SETCONFIG
_REQUEST.fields_by_name['count_request'].message_type = _CURRENTBEACONCOUNT
_REQUEST.fields_by_name['firmware'].message_type = _FIRMWAREUPDATE
_REQUEST.fields_by_name['syslog'].message_type = _GETSYSLOG
_REQUEST.oneofs_by_name['command'].fields.append(
  _REQUEST.fields_by_name['ping'])
_REQUEST.fields_by_name['ping'].containing_oneof = _REQUEST.oneofs_by_name['command']
_REQUEST.oneofs_by_name['command'].fields.append(
  _REQUEST.fields_by_name['config'])
_REQUEST.fields_by_name['config'].containing_oneof = _REQUEST.oneofs_by_name['command']
_REQUEST.oneofs_by_name['command'].fields.append(
  _REQUEST.fields_by_name['reboot'])
_REQUEST.fields_by_name['reboot'].containing_oneof = _REQUEST.oneofs_by_name['command']
_REQUEST.oneofs_by_name['command'].fields.append(
  _REQUEST.fields_by_name['settings'])
_REQUEST.fields_by_name['settings'].containing_oneof = _REQUEST.oneofs_by_name['command']
_REQUEST.oneofs_by_name['command'].fields.append(
  _REQUEST.fields_by_name['count_request'])
_REQUEST.fields_by_name['count_request'].containing_oneof = _REQUEST.oneofs_by_name['command']
_REQUEST.oneofs_by_name['command'].fields.append(
  _REQUEST.fields_by_name['firmware'])
_REQUEST.fields_by_name['firmware'].containing_oneof = _REQUEST.oneofs_by_name['command']
_REQUEST.oneofs_by_name['command'].fields.append(
  _REQUEST.fields_by_name['syslog'])
_REQUEST.fields_by_name['syslog'].containing_oneof = _REQUEST.oneofs_by_name['command']
_SETCONFIG.fields_by_name['values'].message_type = _CONFIGVALUE
_GETCONFIGRESPONSE.fields_by_name['values'].message_type = _CONFIGVALUE
_CONFIGLIST.fields_by_name['entries'].message_type = _GETCONFIGRESPONSE
_CONFIGVALUE.fields_by_name['list'].message_type = _CONFIGLIST
_CONFIGVALUE.fields_by_name['string_array'].message_type = _STRINGARRAY
_CONFIGVALUE.oneofs_by_name['value'].fields.append(
  _CONFIGVALUE.fields_by_name['value_string'])
_CONFIGVALUE.fields_by_name['value_string'].containing_oneof = _CONFIGVALUE.oneofs_by_name['value']
_CONFIGVALUE.oneofs_by_name['value'].fields.append(
  _CONFIGVALUE.fields_by_name['value_double'])
_CONFIGVALUE.fields_by_name['value_double'].containing_oneof = _CONFIGVALUE.oneofs_by_name['value']
_CONFIGVALUE.oneofs_by_name['value'].fields.append(
  _CONFIGVALUE.fields_by_name['value_integer'])
_CONFIGVALUE.fields_by_name['value_integer'].containing_oneof = _CONFIGVALUE.oneofs_by_name['value']
_CONFIGVALUE.oneofs_by_name['value'].fields.append(
  _CONFIGVALUE.fields_by_name['value_boolean'])
_CONFIGVALUE.fields_by_name['value_boolean'].containing_oneof = _CONFIGVALUE.oneofs_by_name['value']
_CONFIGVALUE.oneofs_by_name['value'].fields.append(
  _CONFIGVALUE.fields_by_name['list'])
_CONFIGVALUE.fields_by_name['list'].containing_oneof = _CONFIGVALUE.oneofs_by_name['value']
_CONFIGVALUE.oneofs_by_name['value'].fields.append(
  _CONFIGVALUE.fields_by_name['string_array'])
_CONFIGVALUE.fields_by_name['string_array'].containing_oneof = _CONFIGVALUE.oneofs_by_name['value']
DESCRIPTOR.message_types_by_name['Response'] = _RESPONSE
DESCRIPTOR.message_types_by_name['Request'] = _REQUEST
DESCRIPTOR.message_types_by_name['Ping'] = _PING
DESCRIPTOR.message_types_by_name['Reboot'] = _REBOOT
DESCRIPTOR.message_types_by_name['CurrentBeaconCount'] = _CURRENTBEACONCOUNT
DESCRIPTOR.message_types_by_name['GetSyslog'] = _GETSYSLOG
DESCRIPTOR.message_types_by_name['GetConfig'] = _GETCONFIG
DESCRIPTOR.message_types_by_name['SetConfig'] = _SETCONFIG
DESCRIPTOR.message_types_by_name['GetConfigResponse'] = _GETCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['CurrentBeaconCountResponse'] = _CURRENTBEACONCOUNTRESPONSE
DESCRIPTOR.message_types_by_name['ConfigList'] = _CONFIGLIST
DESCRIPTOR.message_types_by_name['StringArray'] = _STRINGARRAY
DESCRIPTOR.message_types_by_name['ConfigValue'] = _CONFIGVALUE
DESCRIPTOR.message_types_by_name['FirmwareUpdate'] = _FIRMWAREUPDATE
DESCRIPTOR.message_types_by_name['HealthCheck'] = _HEALTHCHECK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Response = _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSE,
  '__module__' : 'c3loc.proto.management_pb2'
  # @@protoc_insertion_point(class_scope:Response)
  })
_sym_db.RegisterMessage(Response)

Request = _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
  'DESCRIPTOR' : _REQUEST,
  '__module__' : 'c3loc.proto.management_pb2'
  # @@protoc_insertion_point(class_scope:Request)
  })
_sym_db.RegisterMessage(Request)

Ping = _reflection.GeneratedProtocolMessageType('Ping', (_message.Message,), {
  'DESCRIPTOR' : _PING,
  '__module__' : 'c3loc.proto.management_pb2'
  # @@protoc_insertion_point(class_scope:Ping)
  })
_sym_db.RegisterMessage(Ping)

Reboot = _reflection.GeneratedProtocolMessageType('Reboot', (_message.Message,), {
  'DESCRIPTOR' : _REBOOT,
  '__module__' : 'c3loc.proto.management_pb2'
  # @@protoc_insertion_point(class_scope:Reboot)
  })
_sym_db.RegisterMessage(Reboot)

CurrentBeaconCount = _reflection.GeneratedProtocolMessageType('CurrentBeaconCount', (_message.Message,), {
  'DESCRIPTOR' : _CURRENTBEACONCOUNT,
  '__module__' : 'c3loc.proto.management_pb2'
  # @@protoc_insertion_point(class_scope:CurrentBeaconCount)
  })
_sym_db.RegisterMessage(CurrentBeaconCount)

GetSyslog = _reflection.GeneratedProtocolMessageType('GetSyslog', (_message.Message,), {
  'DESCRIPTOR' : _GETSYSLOG,
  '__module__' : 'c3loc.proto.management_pb2'
  # @@protoc_insertion_point(class_scope:GetSyslog)
  })
_sym_db.RegisterMessage(GetSyslog)

GetConfig = _reflection.GeneratedProtocolMessageType('GetConfig', (_message.Message,), {
  'DESCRIPTOR' : _GETCONFIG,
  '__module__' : 'c3loc.proto.management_pb2'
  # @@protoc_insertion_point(class_scope:GetConfig)
  })
_sym_db.RegisterMessage(GetConfig)

SetConfig = _reflection.GeneratedProtocolMessageType('SetConfig', (_message.Message,), {
  'DESCRIPTOR' : _SETCONFIG,
  '__module__' : 'c3loc.proto.management_pb2'
  # @@protoc_insertion_point(class_scope:SetConfig)
  })
_sym_db.RegisterMessage(SetConfig)

GetConfigResponse = _reflection.GeneratedProtocolMessageType('GetConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCONFIGRESPONSE,
  '__module__' : 'c3loc.proto.management_pb2'
  # @@protoc_insertion_point(class_scope:GetConfigResponse)
  })
_sym_db.RegisterMessage(GetConfigResponse)

CurrentBeaconCountResponse = _reflection.GeneratedProtocolMessageType('CurrentBeaconCountResponse', (_message.Message,), {
  'DESCRIPTOR' : _CURRENTBEACONCOUNTRESPONSE,
  '__module__' : 'c3loc.proto.management_pb2'
  # @@protoc_insertion_point(class_scope:CurrentBeaconCountResponse)
  })
_sym_db.RegisterMessage(CurrentBeaconCountResponse)

ConfigList = _reflection.GeneratedProtocolMessageType('ConfigList', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGLIST,
  '__module__' : 'c3loc.proto.management_pb2'
  # @@protoc_insertion_point(class_scope:ConfigList)
  })
_sym_db.RegisterMessage(ConfigList)

StringArray = _reflection.GeneratedProtocolMessageType('StringArray', (_message.Message,), {
  'DESCRIPTOR' : _STRINGARRAY,
  '__module__' : 'c3loc.proto.management_pb2'
  # @@protoc_insertion_point(class_scope:StringArray)
  })
_sym_db.RegisterMessage(StringArray)

ConfigValue = _reflection.GeneratedProtocolMessageType('ConfigValue', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGVALUE,
  '__module__' : 'c3loc.proto.management_pb2'
  # @@protoc_insertion_point(class_scope:ConfigValue)
  })
_sym_db.RegisterMessage(ConfigValue)

FirmwareUpdate = _reflection.GeneratedProtocolMessageType('FirmwareUpdate', (_message.Message,), {
  'DESCRIPTOR' : _FIRMWAREUPDATE,
  '__module__' : 'c3loc.proto.management_pb2'
  # @@protoc_insertion_point(class_scope:FirmwareUpdate)
  })
_sym_db.RegisterMessage(FirmwareUpdate)

HealthCheck = _reflection.GeneratedProtocolMessageType('HealthCheck', (_message.Message,), {
  'DESCRIPTOR' : _HEALTHCHECK,
  '__module__' : 'c3loc.proto.management_pb2'
  # @@protoc_insertion_point(class_scope:HealthCheck)
  })
_sym_db.RegisterMessage(HealthCheck)


# @@protoc_insertion_point(module_scope)



"""Add alarm

Revision ID: 5ccf897e51af
Revises: 08158a1b9f0e
Create Date: 2020-10-31 12:47:09.284114

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '5ccf897e51af'
down_revision = '08158a1b9f0e'
branch_labels = None
depends_on = None


def upgrade():
    op.execute("""CREATE TABLE alarms (
    id serial,
    tag_id integer not null,
    start_ts timestamp without time zone default CURRENT_TIMESTAMP,
    last_ts timestamp without time zone default CURRENT_TIMESTAMP,
    ack_ts timestamp without time zone default NULL,
    acknowledged boolean generated always as ( ack_ts IS NOT NULL ) STORED,
    PRIMARY KEY (id),
    CONSTRAINT fk_tag FOREIGN KEY (tag_id) REFERENCES tags(id) ON DELETE CASCADE
    );""")
    op.execute('ALTER TABLE tags ADD COLUMN battery_pct integer;')
    op.execute('ALTER TABLE tags ADD COLUMN distance_cm numeric(4,2);')


def downgrade():
    op.drop_table('alarms')
    op.execute('ALTER TABLE tags DROP COLUMN battery_pct')
    op.execute('ALTER TABLE tags DROP COLUMN distance_cm')




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: c3loc/proto/location.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='c3loc/proto/location.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1a\x63\x33loc/proto/location.proto\"\xec\x02\n\x0eIBeaconSummary\x12\r\n\x05\x63lock\x18\x01 \x01(\x04\x12.\n\x07reports\x18\x02 \x03(\x0b\x32\x1d.IBeaconSummary.IBeaconReport\x1a\x9a\x02\n\rIBeaconReport\x12\x0c\n\x04uuid\x18\x01 \x01(\x0c\x12\x11\n\tmajor_num\x18\x02 \x01(\r\x12\x11\n\tminor_num\x18\x03 \x01(\r\x12\x13\n\x0b\x64istance_cm\x18\x04 \x01(\r\x12\x10\n\x08variance\x18\x05 \x01(\r\x12\r\n\x05\x63ount\x18\x06 \x01(\r\x12\x39\n\x06reason\x18\x07 \x01(\x0e\x32).IBeaconSummary.IBeaconReport.EventReason\x12\x0e\n\x06median\x18\x08 \x01(\r\x12\x0c\n\x04mode\x18\t \x01(\r\"F\n\x0b\x45ventReason\x12\x0c\n\x08RESERVED\x10\x00\x12\t\n\x05\x45NTRY\x10\x01\x12\x08\n\x04\x45XIT\x10\x02\x12\x08\n\x04MOVE\x10\x03\x12\n\n\x06STATUS\x10\x04\"\xfc\x02\n\x11TempBeaconSummary\x12\r\n\x05\x63lock\x18\x01 \x01(\x04\x12\x34\n\x07reports\x18\x02 \x03(\x0b\x32#.TempBeaconSummary.TempBeaconReport\x1a\xa1\x02\n\x10TempBeaconReport\x12\x11\n\tbeacon_id\x18\x01 \x01(\x0c\x12\x0c\n\x04temp\x18\x02 \x01(\r\x12\x0f\n\x07\x62\x61ttery\x18\x03 \x01(\r\x12\x13\n\x0b\x64istance_cm\x18\x04 \x01(\r\x12\x10\n\x08variance\x18\x05 \x01(\r\x12\r\n\x05\x63ount\x18\x06 \x01(\r\x12?\n\x06reason\x18\x07 \x01(\x0e\x32/.TempBeaconSummary.TempBeaconReport.EventReason\x12\x0e\n\x06median\x18\x08 \x01(\r\x12\x0c\n\x04mode\x18\t \x01(\r\"F\n\x0b\x45ventReason\x12\x0c\n\x08RESERVED\x10\x00\x12\t\n\x05\x45NTRY\x10\x01\x12\x08\n\x04\x45XIT\x10\x02\x12\x08\n\x04MOVE\x10\x03\x12\n\n\x06STATUS\x10\x04\"\xb6\x04\n\x0fLABeaconSummary\x12\r\n\x05\x63lock\x18\x01 \x01(\x04\x12\x30\n\x07reports\x18\x02 \x03(\x0b\x32\x1f.LABeaconSummary.LABeaconReport\x1a\xe1\x03\n\x0eLABeaconReport\x12\x11\n\tbeacon_id\x18\x01 \x01(\x0c\x12\x11\n\ttimestamp\x18\x02 \x01(\r\x12\x0f\n\x07nearest\x18\x03 \x01(\r\x12\x14\n\x0cnearest_dist\x18\x04 \x01(\r\x12\x15\n\rnearest_delta\x18\x05 \x01(\r\x12\x13\n\x0b\x64istance_cm\x18\x06 \x01(\r\x12\x10\n\x08variance\x18\x07 \x01(\r\x12\r\n\x05\x63ount\x18\x08 \x01(\r\x12;\n\x06reason\x18\t \x01(\x0e\x32+.LABeaconSummary.LABeaconReport.EventReason\x12\x0e\n\x06median\x18\n \x01(\r\x12\x0c\n\x04mode\x18\x0b \x01(\r\x12\x13\n\x0b\x62\x61ttery_pct\x18\x0c \x01(\r\x12<\n\x06status\x18\r \x01(\x0e\x32,.LABeaconSummary.LABeaconReport.ButtonStatus\"F\n\x0b\x45ventReason\x12\x0c\n\x08RESERVED\x10\x00\x12\t\n\x05\x45NTRY\x10\x01\x12\x08\n\x04\x45XIT\x10\x02\x12\x08\n\x04MOVE\x10\x03\x12\n\n\x06STATUS\x10\x04\"?\n\x0c\x42uttonStatus\x12\x11\n\rNOT_AVAILABLE\x10\x00\x12\x0f\n\x0bNOT_PRESSED\x10\x01\x12\x0b\n\x07PRESSED\x10\x02\x62\x06proto3'
)



_IBEACONSUMMARY_IBEACONREPORT_EVENTREASON = _descriptor.EnumDescriptor(
  name='EventReason',
  full_name='IBeaconSummary.IBeaconReport.EventReason',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESERVED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENTRY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXIT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MOVE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATUS', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=325,
  serialized_end=395,
)
_sym_db.RegisterEnumDescriptor(_IBEACONSUMMARY_IBEACONREPORT_EVENTREASON)

_TEMPBEACONSUMMARY_TEMPBEACONREPORT_EVENTREASON = _descriptor.EnumDescriptor(
  name='EventReason',
  full_name='TempBeaconSummary.TempBeaconReport.EventReason',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESERVED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENTRY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXIT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MOVE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATUS', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=325,
  serialized_end=395,
)
_sym_db.RegisterEnumDescriptor(_TEMPBEACONSUMMARY_TEMPBEACONREPORT_EVENTREASON)

_LABEACONSUMMARY_LABEACONREPORT_EVENTREASON = _descriptor.EnumDescriptor(
  name='EventReason',
  full_name='LABeaconSummary.LABeaconReport.EventReason',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESERVED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ENTRY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXIT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MOVE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATUS', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=325,
  serialized_end=395,
)
_sym_db.RegisterEnumDescriptor(_LABEACONSUMMARY_LABEACONREPORT_EVENTREASON)

_LABEACONSUMMARY_LABEACONREPORT_BUTTONSTATUS = _descriptor.EnumDescriptor(
  name='ButtonStatus',
  full_name='LABeaconSummary.LABeaconReport.ButtonStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NOT_AVAILABLE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOT_PRESSED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRESSED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1284,
  serialized_end=1347,
)
_sym_db.RegisterEnumDescriptor(_LABEACONSUMMARY_LABEACONREPORT_BUTTONSTATUS)


_IBEACONSUMMARY_IBEACONREPORT = _descriptor.Descriptor(
  name='IBeaconReport',
  full_name='IBeaconSummary.IBeaconReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='IBeaconSummary.IBeaconReport.uuid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='major_num', full_name='IBeaconSummary.IBeaconReport.major_num', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minor_num', full_name='IBeaconSummary.IBeaconReport.minor_num', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distance_cm', full_name='IBeaconSummary.IBeaconReport.distance_cm', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variance', full_name='IBeaconSummary.IBeaconReport.variance', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='IBeaconSummary.IBeaconReport.count', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='IBeaconSummary.IBeaconReport.reason', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='median', full_name='IBeaconSummary.IBeaconReport.median', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mode', full_name='IBeaconSummary.IBeaconReport.mode', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _IBEACONSUMMARY_IBEACONREPORT_EVENTREASON,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=113,
  serialized_end=395,
)

_IBEACONSUMMARY = _descriptor.Descriptor(
  name='IBeaconSummary',
  full_name='IBeaconSummary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='clock', full_name='IBeaconSummary.clock', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reports', full_name='IBeaconSummary.reports', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_IBEACONSUMMARY_IBEACONREPORT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31,
  serialized_end=395,
)


_TEMPBEACONSUMMARY_TEMPBEACONREPORT = _descriptor.Descriptor(
  name='TempBeaconReport',
  full_name='TempBeaconSummary.TempBeaconReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='beacon_id', full_name='TempBeaconSummary.TempBeaconReport.beacon_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='temp', full_name='TempBeaconSummary.TempBeaconReport.temp', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='battery', full_name='TempBeaconSummary.TempBeaconReport.battery', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distance_cm', full_name='TempBeaconSummary.TempBeaconReport.distance_cm', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variance', full_name='TempBeaconSummary.TempBeaconReport.variance', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='TempBeaconSummary.TempBeaconReport.count', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='TempBeaconSummary.TempBeaconReport.reason', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='median', full_name='TempBeaconSummary.TempBeaconReport.median', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mode', full_name='TempBeaconSummary.TempBeaconReport.mode', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TEMPBEACONSUMMARY_TEMPBEACONREPORT_EVENTREASON,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=489,
  serialized_end=778,
)

_TEMPBEACONSUMMARY = _descriptor.Descriptor(
  name='TempBeaconSummary',
  full_name='TempBeaconSummary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='clock', full_name='TempBeaconSummary.clock', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reports', full_name='TempBeaconSummary.reports', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TEMPBEACONSUMMARY_TEMPBEACONREPORT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=398,
  serialized_end=778,
)


_LABEACONSUMMARY_LABEACONREPORT = _descriptor.Descriptor(
  name='LABeaconReport',
  full_name='LABeaconSummary.LABeaconReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='beacon_id', full_name='LABeaconSummary.LABeaconReport.beacon_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='LABeaconSummary.LABeaconReport.timestamp', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nearest', full_name='LABeaconSummary.LABeaconReport.nearest', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nearest_dist', full_name='LABeaconSummary.LABeaconReport.nearest_dist', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nearest_delta', full_name='LABeaconSummary.LABeaconReport.nearest_delta', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distance_cm', full_name='LABeaconSummary.LABeaconReport.distance_cm', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variance', full_name='LABeaconSummary.LABeaconReport.variance', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='LABeaconSummary.LABeaconReport.count', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='LABeaconSummary.LABeaconReport.reason', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='median', full_name='LABeaconSummary.LABeaconReport.median', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mode', full_name='LABeaconSummary.LABeaconReport.mode', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='battery_pct', full_name='LABeaconSummary.LABeaconReport.battery_pct', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='LABeaconSummary.LABeaconReport.status', index=12,
      number=13, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LABEACONSUMMARY_LABEACONREPORT_EVENTREASON,
    _LABEACONSUMMARY_LABEACONREPORT_BUTTONSTATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=866,
  serialized_end=1347,
)

_LABEACONSUMMARY = _descriptor.Descriptor(
  name='LABeaconSummary',
  full_name='LABeaconSummary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='clock', full_name='LABeaconSummary.clock', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reports', full_name='LABeaconSummary.reports', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LABEACONSUMMARY_LABEACONREPORT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=781,
  serialized_end=1347,
)

_IBEACONSUMMARY_IBEACONREPORT.fields_by_name['reason'].enum_type = _IBEACONSUMMARY_IBEACONREPORT_EVENTREASON
_IBEACONSUMMARY_IBEACONREPORT.containing_type = _IBEACONSUMMARY
_IBEACONSUMMARY_IBEACONREPORT_EVENTREASON.containing_type = _IBEACONSUMMARY_IBEACONREPORT
_IBEACONSUMMARY.fields_by_name['reports'].message_type = _IBEACONSUMMARY_IBEACONREPORT
_TEMPBEACONSUMMARY_TEMPBEACONREPORT.fields_by_name['reason'].enum_type = _TEMPBEACONSUMMARY_TEMPBEACONREPORT_EVENTREASON
_TEMPBEACONSUMMARY_TEMPBEACONREPORT.containing_type = _TEMPBEACONSUMMARY
_TEMPBEACONSUMMARY_TEMPBEACONREPORT_EVENTREASON.containing_type = _TEMPBEACONSUMMARY_TEMPBEACONREPORT
_TEMPBEACONSUMMARY.fields_by_name['reports'].message_type = _TEMPBEACONSUMMARY_TEMPBEACONREPORT
_LABEACONSUMMARY_LABEACONREPORT.fields_by_name['reason'].enum_type = _LABEACONSUMMARY_LABEACONREPORT_EVENTREASON
_LABEACONSUMMARY_LABEACONREPORT.fields_by_name['status'].enum_type = _LABEACONSUMMARY_LABEACONREPORT_BUTTONSTATUS
_LABEACONSUMMARY_LABEACONREPORT.containing_type = _LABEACONSUMMARY
_LABEACONSUMMARY_LABEACONREPORT_EVENTREASON.containing_type = _LABEACONSUMMARY_LABEACONREPORT
_LABEACONSUMMARY_LABEACONREPORT_BUTTONSTATUS.containing_type = _LABEACONSUMMARY_LABEACONREPORT
_LABEACONSUMMARY.fields_by_name['reports'].message_type = _LABEACONSUMMARY_LABEACONREPORT
DESCRIPTOR.message_types_by_name['IBeaconSummary'] = _IBEACONSUMMARY
DESCRIPTOR.message_types_by_name['TempBeaconSummary'] = _TEMPBEACONSUMMARY
DESCRIPTOR.message_types_by_name['LABeaconSummary'] = _LABEACONSUMMARY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

IBeaconSummary = _reflection.GeneratedProtocolMessageType('IBeaconSummary', (_message.Message,), {

  'IBeaconReport' : _reflection.GeneratedProtocolMessageType('IBeaconReport', (_message.Message,), {
    'DESCRIPTOR' : _IBEACONSUMMARY_IBEACONREPORT,
    '__module__' : 'c3loc.proto.location_pb2'
    # @@protoc_insertion_point(class_scope:IBeaconSummary.IBeaconReport)
    })
  ,
  'DESCRIPTOR' : _IBEACONSUMMARY,
  '__module__' : 'c3loc.proto.location_pb2'
  # @@protoc_insertion_point(class_scope:IBeaconSummary)
  })
_sym_db.RegisterMessage(IBeaconSummary)
_sym_db.RegisterMessage(IBeaconSummary.IBeaconReport)

TempBeaconSummary = _reflection.GeneratedProtocolMessageType('TempBeaconSummary', (_message.Message,), {

  'TempBeaconReport' : _reflection.GeneratedProtocolMessageType('TempBeaconReport', (_message.Message,), {
    'DESCRIPTOR' : _TEMPBEACONSUMMARY_TEMPBEACONREPORT,
    '__module__' : 'c3loc.proto.location_pb2'
    # @@protoc_insertion_point(class_scope:TempBeaconSummary.TempBeaconReport)
    })
  ,
  'DESCRIPTOR' : _TEMPBEACONSUMMARY,
  '__module__' : 'c3loc.proto.location_pb2'
  # @@protoc_insertion_point(class_scope:TempBeaconSummary)
  })
_sym_db.RegisterMessage(TempBeaconSummary)
_sym_db.RegisterMessage(TempBeaconSummary.TempBeaconReport)

LABeaconSummary = _reflection.GeneratedProtocolMessageType('LABeaconSummary', (_message.Message,), {

  'LABeaconReport' : _reflection.GeneratedProtocolMessageType('LABeaconReport', (_message.Message,), {
    'DESCRIPTOR' : _LABEACONSUMMARY_LABEACONREPORT,
    '__module__' : 'c3loc.proto.location_pb2'
    # @@protoc_insertion_point(class_scope:LABeaconSummary.LABeaconReport)
    })
  ,
  'DESCRIPTOR' : _LABEACONSUMMARY,
  '__module__' : 'c3loc.proto.location_pb2'
  # @@protoc_insertion_point(class_scope:LABeaconSummary)
  })
_sym_db.RegisterMessage(LABeaconSummary)
_sym_db.RegisterMessage(LABeaconSummary.LABeaconReport)


# @@protoc_insertion_point(module_scope)



#!/bin/env python
"""Reference Implementation of v1 C3 Security Beacon Auth Server."""
import asyncio
import asyncpg
import os
import signal

import click

from .protocol import ListenerProtocol
from ..db import init_db_pool


def default_handler(loop, context):
    print(f"Unhandled exception: {context['message']}", context)
    loop.stop()


@click.command()
@click.option('--port', '-p', default=9999)
def main(port) -> None:
    loop = asyncio.get_event_loop()
    loop.set_exception_handler(default_handler)
    if signal is not None and os.name != 'nt':
        loop.add_signal_handler(signal.SIGINT, loop.stop)

    db_pool = loop.run_until_complete(init_db_pool())
    ListenerProtocol.db_pool = db_pool

    def start_server(loop):
        return loop.create_server(ListenerProtocol, '0.0.0.0', port)
    server = loop.run_until_complete(start_server(loop))
    print("Listening on port {}".format(port))
    loop.run_forever()
    server.close()
    loop.close()


if __name__ == '__main__':
    main()



import asyncpg

from .config import CONFIG


async def init_db_pool():
    db_url = f"postgres://{CONFIG['DB_USER']}:{CONFIG['DB_PASSWORD']}@{CONFIG['DB_HOST']}/{CONFIG['DB_NAME']}"
    db_url_redacted = f"postgres://{CONFIG['DB_USER']}:*****@{CONFIG['DB_HOST']}"
    print(f"Connecting to {db_url_redacted}")
    pool = await asyncpg.create_pool(dsn=db_url, min_size=2, max_size=4)
    return pool
